@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+# Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ from functools import wraps
 import imp
 import re
 import traceback
-import collections
+import collections.abc
 
 from znc_core import *
 
@@ -125,7 +125,7 @@ class Timer:
         pass
 
 
-class ModuleNVIter(collections.Iterator):
+class ModuleNVIter(collections.abc.Iterator):
     def __init__(self, cmod):
         self._cmod = cmod
         self.it = cmod.BeginNV_()
@@ -138,7 +138,7 @@ class ModuleNVIter(collections.Iterator):
         return res
 
 
-class ModuleNV(collections.MutableMapping):
+class ModuleNV(collections.abc.MutableMapping):
     def __init__(self, cmod):
         self._cmod = cmod
 
@@ -957,7 +957,7 @@ CModule.AddSocket = FreeOwnership(func=CModule.AddSocket)
 CModule.AddSubPage = FreeOwnership(func=CModule.AddSubPage)
 
 
-class ModulesIter(collections.Iterator):
+class ModulesIter(collections.abc.Iterator):
     def __init__(self, cmod):
         self._cmod = cmod
 
